@@ -1,5 +1,5 @@
 package List::Compare::Base::_Auxiliary;
-$VERSION = 0.42;
+$VERSION = 0.43;
 use Carp;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw|
@@ -14,6 +14,7 @@ use Carp;
     _calculate_union_seen_only
     _calculate_hash_intersection
     _calculate_hash_shared
+    _calculate_sharedref
     _subset_subengine
     _chart_engine_regular
     _chart_engine_multiple
@@ -51,6 +52,7 @@ use Carp;
         _calculate_union_seen_only
         _calculate_hash_intersection
         _calculate_hash_shared
+        _calculate_sharedref
     ) ],
     checker => [ qw(
         _argument_checker_0
@@ -312,6 +314,24 @@ sub _calculate_hash_shared {
     return \%shared;
 }
 
+sub _calculate_sharedref {
+    my $seenrefsref = shift;
+
+    my %intermediate = ();
+    for my $href (@{$seenrefsref}) {
+       my %this = map { $_ => 1 } keys(%{$href});
+        for my $k (keys %this) {;
+            $intermediate{$k}++;
+        };
+    }
+
+    my $sharedref;
+    for my $k (keys %intermediate) {
+        $sharedref->{$k}++ if $intermediate{$k} > 1;
+    }
+    return $sharedref;
+}
+
 sub _subset_subengine {
     my $aref = shift;
     my (@xsubset);
@@ -749,8 +769,8 @@ List::Compare::Base::_Auxiliary - Internal use only
 
 =head1 VERSION
 
-This document refers to version 0.42 of List::Compare::Base::_Auxiliary.
-This version was released February 11 2015.
+This document refers to version 0.43 of List::Compare::Base::_Auxiliary.
+This version was released February 12 2015.
 
 =head1 SYNOPSIS
 
@@ -762,7 +782,7 @@ List::Compare::Functional.  They are not intended to be publicly callable.
 James E. Keenan (jkeenan@cpan.org).  When sending correspondence, please
 include 'List::Compare' or 'List-Compare' in your subject line.
 
-Creation date:  May 20, 2002.  Last modification date:  February 11 2015.
+Creation date:  May 20, 2002.  Last modification date:  February 12 2015.
 Copyright (c) 2002-15 James E. Keenan.  United States.  All rights reserved.
 This is free software and may be distributed under the same terms as Perl
 itself.
