@@ -1,5 +1,5 @@
 package List::Compare::Functional;
-$VERSION = 0.42;
+$VERSION = 0.43;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw|
     get_intersection
@@ -253,18 +253,7 @@ sub _symmetric_difference_engine {
 
     my $unionref = _calculate_union_only($seenrefsref);
 
-    my %intermediate = ();
-    for my $href (@{$seenrefsref}) {
-       my %this = map { $_ => 1 } keys(%{$href});
-        for my $k (keys %this) {;
-            $intermediate{$k}++;
-        };
-    }
-
-    my $sharedref;
-    for my $k (keys %intermediate) {
-        $sharedref->{$k}++ if $intermediate{$k} > 1;
-    }
+    my $sharedref = _calculate_sharedref($seenrefsref);
 
     my (@symmetric_difference);
     for my $k (keys %{$unionref}) {
@@ -289,12 +278,9 @@ sub get_shared_ref {
 
 sub _shared_engine {
     my $seenrefsref = _calc_seen1(@_);
-    # Calculate @shared
-    # Inputs:  %xintersection
-    my $xintersectionref = _calculate_xintersection_only($seenrefsref);
-    my $sharedref = _calculate_hash_shared($xintersectionref);
-    my @shared = keys %{$sharedref};
-    return \@shared;
+
+    my $sharedref = _calculate_sharedref($seenrefsref);
+    return [ keys %{$sharedref} ];
 }
 
 sub get_nonintersection {
@@ -544,8 +530,8 @@ List::Compare::Functional - Compare elements of two or more lists
 
 =head1 VERSION
 
-This document refers to version 0.42 of List::Compare::Functional.
-This version was released February 11 2015.  The first released
+This document refers to version 0.43 of List::Compare::Functional.
+This version was released February 12 2015.  The first released
 version of List::Compare::Functional was v0.21.  Its version numbers
 are set to be consistent with the other parts of the List::Compare
 distribution.
@@ -1709,7 +1695,7 @@ James E. Keenan (jkeenan@cpan.org).  When sending correspondence, please
 include 'List::Compare::Functional' or 'List-Compare-Functional' in your
 subject line.
 
-Creation date:  May 20, 2002.  Last modification date:  February 11 2015.
+Creation date:  May 20, 2002.  Last modification date:  February 12 2015.
 Copyright (c) 2002-15 James E. Keenan.  United States.  All rights reserved.
 This is free software and may be distributed under the same terms as Perl
 itself.
